@@ -1,4 +1,6 @@
 import base64
+from socketdev.log import log
+
 import requests
 from socketdev.core.classes import Response
 from socketdev.exceptions import (
@@ -52,8 +54,9 @@ class API:
         def format_headers(headers_dict):
             return "\n".join(f"{k}: {v}" for k, v in headers_dict.items())
 
+        start_time = time.time()
         try:
-            start_time = time.time()
+            
             response = requests.request(
                 method.upper(), url, headers=headers, data=payload, files=files, timeout=self.request_timeout
             )
@@ -68,17 +71,21 @@ class API:
                 try:
                     error_message = response.json().get("error", {}).get("message", "")
                     if "Insufficient permissions for API method" in error_message:
-                        raise APIInsufficientPermissions(f"{error_message}{path_str}{headers_str}")
+                        log.error(f"{error_message}{path_str}{headers_str}")
+                        raise APIInsufficientPermissions()
                     elif "Organization not allowed" in error_message:
-                        raise APIOrganizationNotAllowed(f"{error_message}{path_str}{headers_str}")
+                        log.error(f"{error_message}{path_str}{headers_str}")
+                        raise APIOrganizationNotAllowed()
                     elif "Insufficient max quota" in error_message:
-                        raise APIInsufficientQuota(f"{error_message}{path_str}{headers_str}")
+                        log.error(f"{error_message}{path_str}{headers_str}")
+                        raise APIInsufficientQuota()
                     else:
                         raise APIAccessDenied(f"{error_message or 'Access denied'}{path_str}{headers_str}")
                 except ValueError:
                     raise APIAccessDenied(f"Access denied{path_str}{headers_str}")
             if response.status_code == 404:
-                raise APIResourceNotFound(f"Path not found {path}{path_str}{headers_str}")
+                log.error(f"Path not found {path}{path_str}{headers_str}")
+                raise APIResourceNotFound()
             if response.status_code == 429:
                 retry_after = response.headers.get("retry-after")
                 if retry_after:
@@ -91,23 +98,33 @@ class API:
                         time_msg = f" Retry after: {retry_after}"
                 else:
                     time_msg = ""
-                raise APIInsufficientQuota(f"Insufficient quota for API route.{time_msg}{path_str}{headers_str}")
+                log.error(f"Insufficient quota for API route.{time_msg}{path_str}{headers_str}")
+                raise APIInsufficientQuota()
             if response.status_code == 502:
-                raise APIBadGateway(f"Upstream server error{path_str}{headers_str}")
+                log.error(f"Upstream server error{path_str}{headers_str}")
+                raise APIBadGateway()
             if response.status_code >= 400:
-                raise APIFailure(
-                    f"Bad Request: HTTP original_status_code:{response.status_code}{path_str}{headers_str}",
-                    status_code=500,
+                try:
+                    error_json = response.json()
+                except Exception:
+                    error_json = None
+                error_message = error_json.get("error", {}).get("message") if error_json else response.text
+                error = (
+                    f"Bad Request: HTTP original_status_code:{response.status_code}{path_str}{headers_str}\n"
+                    f"Error message: {error_message}"
                 )
+                log.error(error)
+                raise APIFailure(error)
 
             return response
-
         except Timeout:
             request_duration = time.time() - start_time
-            raise APITimeout(f"Request timed out after {request_duration:.2f} seconds")
+            log.error(f"Request timed out after {request_duration:.2f} seconds")
+            raise APITimeout()
         except ConnectionError as error:
             request_duration = time.time() - start_time
-            raise APIConnectionError(f"Connection error after {request_duration:.2f} seconds: {error}")
+            log.error(f"Connection error after {request_duration:.2f} seconds: {error}")
+            raise APIConnectionError()
         except (
             APIAccessDenied,
             APIInsufficientQuota,
@@ -123,4 +140,5 @@ class API:
             raise
         except Exception as error:
             # Only truly unexpected errors get wrapped in a generic APIFailure
-            raise APIFailure(f"Unexpected error: {error}", status_code=500)
+            log.error(f"Unexpected error: {error}")
+            raise APIFailure()
